@@ -1,16 +1,23 @@
 import commands
 import os.path
 import gtk
+import gobject
 import random
 
-VERSION = "0.3.0"
+VERSION = "0.3.5.1"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
+# general settings
 db_file = os.path.expanduser("~/.musicdb")
 music_dirs = ("~/music/", "/media/mmc2", "/media/mmc1")
 blacklist_dirs = ("/media/mmc2/map",)
 known_exts = ("mp3", "ogg")
 
+if IS_MAEMO:
+    import osso
+    context = osso.Context("youamp", VERSION, False)
+
+# device specific settings
 if IS_MAEMO:
     MAX_VOL = 10.0
     img_path = "/usr/share/youamp/%s"
@@ -18,7 +25,7 @@ else:
     MAX_VOL = 4.0
     img_path = "data/%s"
 
-class Playlist(gtk.ListStore):
+class Playlist(gtk.ListStore):    
     def __init__(self, playlist=None):
         gtk.ListStore.__init__(self, object)
         
@@ -70,10 +77,4 @@ class Song(dict):
             self["album"] = self.data[3]
         else:
             self.uri = data
-    
-    def get_tuple(self):
-        if not self.data is None:
-            return self.data
-        else:
-            return (self.uri, self["title"], self["artist"] , self["album"])
 
