@@ -10,18 +10,22 @@ class Config(gconf.Client):
         gconf.Client.__init__(self)
         self.add_dir("/apps/youamp", gconf.CLIENT_PRELOAD_RECURSIVE)
         
-        if not self.has_key("volume"):
+        if not self.has_key("volume") or not self.has_key("order-by"):
             # write default config
-            self["volume"] = 0.5
-            self["search-str"] = ""
-            self["search-artist"] = ""
-            self["search-album"] = ""
-            self["pos"] = 0
-            self["shuffle"] = False
-            self["is-browser"] = False
-            self["rg-preamp"] = 0     # preamp to adjust the default of 89db (value: db)
-            self["no-rg-preamp"] = -10  # amp value to be used if no rg info is available (value: db)
+            self._reset()
     
+    def _reset(self):   
+        self["volume"] = 0.5
+        self["search-str"] = ""
+        self["search-artist"] = ""
+        self["search-album"] = ""
+        self["pos"] = 0
+        self["shuffle"] = False
+        self["is-browser"] = False
+        self["order-by"] = "artist"
+        self["rg-preamp"] = 0     # preamp to adjust the default of 89db (value: db)
+        self["no-rg-preamp"] = -10  # amp value to be used if no rg info is available (value: db)
+                
     def notify_add(self, k, f):
         gconf.Client.notify_add(self, "/apps/youamp/"+k, f)
 
